package ru.ldeloff.servermonitorbot.service;

import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.telegram.telegrambots.meta.api.methods.send.SendMessage;
import org.telegram.telegrambots.meta.api.objects.Update;
import org.telegram.telegrambots.meta.exceptions.TelegramApiException;
import ru.ldeloff.servermonitorbot.controller.TelegramBotController;
import ru.ldeloff.servermonitorbot.repository.SshRepository;
import ru.ldeloff.servermonitorbot.utils.ui.TelegramBotKeyboard;
import ru.ldeloff.servermonitorbot.utils.ui.uname.UnameChatButtonAggregate;

@Slf4j
@Service
public class TelegramBotServiceImpl implements TelegramBotService {
    final TelegramBotKeyboard telegramBotKeyboard;
    final SshRepository sshRepository;
    final UnameChatButtonAggregate unameChatButtonAggregate;

    public TelegramBotServiceImpl(TelegramBotKeyboard telegramBotKeyboard, SshRepository sshRepository, UnameChatButtonAggregate unameChatButtonAggregate) {
        this.telegramBotKeyboard = telegramBotKeyboard;
        this.sshRepository = sshRepository;
        this.unameChatButtonAggregate = unameChatButtonAggregate;
    }
    @Override
    public void switchToMainMenu(Update update, TelegramBotController bot) {
        SendMessage message = new SendMessage();
        long chatId = 0L;
        try {
            chatId = update.getMessage().getChatId();
        } catch (Exception e) {
            chatId = update.getCallbackQuery().getMessage().getChatId();

        }
        message.setText("Неверная команда и или формат. Попробуем сначала.");
        message.setChatId(chatId);
        sendMessage(telegramBotKeyboard.uiForm(message), bot);
    }
    @Override
    public void getStatusSessions(Update update, TelegramBotController bot) {
        SendMessage message = new SendMessage();
        long chatId = update.getMessage().getChatId();
        message.setText(String.valueOf(sshRepository.getStatusSessions()));
        message.setChatId(chatId);
        sendMessage(message, bot);
    }
    @Override
    public void sendUnameAggregate(Update update, TelegramBotController bot) {
        SendMessage message = new SendMessage();
        long chatId = update.getMessage().getChatId();
        message.setText(String.valueOf(sshRepository.getStatusSessions()));
        message.setChatId(chatId);
        sendMessage(unameChatButtonAggregate.uiForm(message), bot);
    }
    private void sendMessage(SendMessage message, TelegramBotController bot) {
        try {
            bot.execute(message);
        } catch (TelegramApiException e) {
            e.printStackTrace();
            log.warn(e.getMessage());
        }
    }
}
